<?php

namespace Drupal\views_css_grid;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

trait ViewsCssGridTraits
{
  protected function getViewsCssOptions()
  {
    $options['mode'] = ['default' => 'auto-fill'];
    $options['grid_auto_flow'] = ['default' => null];
    $options['gap'] = ['default' => '24px'];
    $options['minmax'] = [
      'contains' => [
        'min' => ['default' => '300px'],
        'max' => ['default' => '1fr']
      ]
    ];
    $options['justify_items'] = ['default' => null];
    $options['align_items'] = ['default' => null];
    $options['justify_content'] = ['default' => null];
    $options['align_content'] = ['default' => null];
    return $options;
  }

  public function buildForm(&$form) {
    $form['cheatsheet'] = [
      '#type' => 'link',
      '#title' => "Click to open a nice 'CSS Grid' Reference in a new tab.",
      '#url' => Url::fromUri('https://grid.malven.co/'),
      '#attributes' => [
        'target' => '_blank'
      ]
    ];

    $form['mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Mode'),
      '#options' => [
        'auto-fill' => 'repeat: auto-fill',
        'auto-fit' => 'repeat: auto-fit',
        'custom' => 'custom'
      ],
      '#default_value' => $this->options['mode'],
    ];

    $form['gap'] = [
      '#type' => 'textfield',
      '#title' => 'gap',
      '#default_value' => $this->options['gap'],
      '#attributes' => ['size' => '16']
    ];

    $form['grid_auto_flow'] = [
      '#type' => 'select',
      '#title' => 'grid-auto-flow',
      '#options' => [
        null => '<default>',
        'row' => 'row',
        'column' => 'column',
        'dense' => 'dense',
      ],
      '#default_value' => $this->options['auto_flow'],
    ];

    $form['minmax'] = [
      '#type' => 'fieldset',
      '#title' => 'minmax',
      'min' => [
        '#type' => 'textfield',
        '#title' => 'min',
        '#default_value' => $this->options['minmax']['min'],
        '#attributes' => ['size' => '16']
      ],
      'max' => [
        '#type' => 'textfield',
        '#title' => 'max',
        '#default_value' => $this->options['minmax']['max'],
        '#attributes' => ['size' => '8']
      ]
    ];

    $form['align_justify'] = [
      '#type' => 'fieldset',
      '#title' => 'Align and Justify',
    ];

    foreach (['justify_items', 'align_items', 'justify_content', 'align_content'] as $property) {
      $options = [
        null => '<default>',
        'start' => t('start'),
        'end' => t('end'),
        'center' => t('center'),
        'stretch' => t('stretch'),
      ];

      if(str_ends_with($property, 'content')) {
        $options += [
          'space-around' => t('space-around'),
          'space-between' => t('space-between'),
          'space-evenly' => t('space-evenly'),
        ];
      }

      $form['align_justify'][$property] = [
        '#type' => 'select',
        '#title' => str_replace('_', '-', $property),
        '#options' => $options,
        '#default_value' => $this->options[$property],
      ];
    }
  }
}
